// Copyright 2025 RnD Center "ELVEES", JSC

/*! \file
 *  \brief Заголовочный файл с функциями тестирования библиотеки
 */

#ifndef TEST_H
#define TEST_H

#include <stdbool.h>
#include <math.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>

#include "common.h"

#include <elcore50-signal-lib/fft.h>
#include <elcore50-signal-lib/types_converter.h>
#include <elcore50-signal-lib/reference.h>

/*!
 *  \fn int test_fft_float_1d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления прямого БПФ для типа float
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_fft_float_1d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_fft_hfloat_1d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления прямого БПФ для типа float16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_fft_hfloat_1d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_fft_fract_1d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления прямого БПФ для типа fractional16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_fft_fract_1d(const int fft_min_size, const int fft_max_size);

/*!
 *  \fn int test_ifft_float_1d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления обратного БПФ для типа float
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_ifft_float_1d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_ifft_hfloat_1d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления обратного БПФ для типа float16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_ifft_hfloat_1d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_ifft_fract_1d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления обратного БПФ для типа fractional16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_ifft_fract_1d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_fft_float_2d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления прямого двумерного БПФ для типа float
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_fft_float_2d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_fft_hfloat_2d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления прямого двумерного БПФ для типа float16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_fft_hfloat_2d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_fft_fract_2d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления прямого двумерного БПФ для типа fractional16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_fft_fract_2d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_ifft_float_2d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления обратного двумерного БПФ для типа float
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_ifft_float_2d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_ifft_hfloat_2d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления обратного двумерного БПФ для типа float16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */

int test_ifft_hfloat_2d(const int fft_min_size, const int fft_max_size);
/*!
 *  \fn int test_ifft_fract_2d(const int fft_min_size, const int fft_max_size)
 *  \brief Тестирование функции вычисления обратного двумерного БПФ для типа fractional16
 *  \param[in] fft_min_size минимальный размер преобразования
 *  \param[in] fft_max_size максимальный размер преобразования
 *  \return
 *      - \b int количество ошибок
 */
int test_ifft_fract_2d(const int fft_min_size, const int fft_max_size);

#endif
